<?php

namespace Drupal\entity_usage_explorer\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\entity_usage_explorer\UsageService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Controller for entity usage overview page.
 */
class UsageOverviewController extends ControllerBase implements ContainerInjectionInterface {

  /**
   * Used to get entity usage data.
   *
   * @var \Drupal\entity_usage_explorer\UsageService
   */
  protected $entityUsageService;

  /**
   * Constructs a UsageOverviewController object.
   *
   * @param \Drupal\entity_usage_explorer\UsageService $entity_usage_service
   *   The entity usage service.
   */
  public function __construct(UsageService $entity_usage_service) {
    $this->entityUsageService = $entity_usage_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('entity_usage_explorer.usage')
    );
  }

  /**
   * Returns usage count for a given entity type and entity ID.
   */
  public function getUsagePage($entity_type, $entity_id) {
    $data = $this->entityUsageService->getEntityUsage($entity_type, $entity_id);

    return [
      '#theme' => 'entity_usage_overview',
      '#target_entity_type' => $entity_type,
      '#target_entity_id' => $entity_id,
      '#data' => $data,
    ];
  }

  /**
   * Callback for usage overview page title.
   */
  public function getTitle($entity_type, $entity_id): TranslatableMarkup {
    return $this->t("Usage statistics for: <em>@entity_type(@entity_id)</em>", [
      '@entity_type' => $entity_type,
      '@entity_id' => $entity_id,
    ]);
  }

}
